package com.ruoyi.mall.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallGoodsTagMapper;
import com.ruoyi.mall.domain.MallGoodsTag;
import com.ruoyi.mall.service.IMallGoodsTagService;

/**
 * 商品标签Service业务层处理
 *
 * @author ruoyi
 * @date 2022-06-28
 */
@Service
public class MallGoodsTagServiceImpl implements IMallGoodsTagService
{
    @Autowired
    private MallGoodsTagMapper mallGoodsTagMapper;

    /**
     * 查询商品标签
     *
     * @param id 商品标签主键
     * @return 商品标签
     */
    @Override
    public MallGoodsTag selectMallGoodsTagById(Integer id)
    {
        return mallGoodsTagMapper.selectMallGoodsTagById(id);
    }

    /**
     * 查询商品标签列表
     *
     * @param mallGoodsTag 商品标签
     * @return 商品标签
     */
    @Override
    public List<MallGoodsTag> selectMallGoodsTagList(MallGoodsTag mallGoodsTag)
    {
        return mallGoodsTagMapper.selectMallGoodsTagList(mallGoodsTag);
    }

    /**
     * 查询商品标签列表
     *
     * @return 商品标签
     */
    @Override
    public List<MallGoodsTag> getGoodsTags()
    {
        return mallGoodsTagMapper.getGoodsTags();
    }

    /**
     * 新增商品标签
     *
     * @param mallGoodsTag 商品标签
     * @return 结果
     */
    @Override
    public int insertMallGoodsTag(MallGoodsTag mallGoodsTag)
    {
        mallGoodsTag.setCreateAt(DateUtils.getTime());
        mallGoodsTag.setDelFlag(0);
        return mallGoodsTagMapper.insertMallGoodsTag(mallGoodsTag);
    }

    /**
     * 修改商品标签
     *
     * @param mallGoodsTag 商品标签
     * @return 结果
     */
    @Override
    public int updateMallGoodsTag(MallGoodsTag mallGoodsTag)
    {
        mallGoodsTag.setUpdateAt(DateUtils.getTime());
        return mallGoodsTagMapper.updateMallGoodsTag(mallGoodsTag);
    }

    /**
     * 批量删除商品标签
     *
     * @param ids 需要删除的商品标签主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsTagByIds(Integer[] ids)
    {
        return mallGoodsTagMapper.deleteMallGoodsTagByIds(ids);
    }

    /**
     * 删除商品标签信息
     *
     * @param id 商品标签主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsTagById(Integer id)
    {
        return mallGoodsTagMapper.deleteMallGoodsTagById(id);
    }
}
